@@ -3,7 +3,7 @@
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 """Interface for classes to serialize to HDF5."""
 
-from pyiron_base.generic.hdfio import ProjectHDFio
+from pyiron_base.storage.hdfio import ProjectHDFio
 
 from abc import ABC, abstractmethod
 
